@@ -13,11 +13,9 @@ import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 
 
-def data_gen(t=0):
-    cnt = 0
-    while cnt < 1000:
-        cnt += 1
-        t += 0.1
+def data_gen():
+    for cnt in range(1000):
+        t = cnt / 10
         yield t, np.sin(2*np.pi*t) * np.exp(-t/10.)
 
 
