@@ -8,7 +8,7 @@ from matplotlib import rc_context
 from matplotlib.testing.decorators import image_comparison
 import matplotlib.pyplot as plt
 from matplotlib.colors import (BoundaryNorm, LogNorm, PowerNorm, Normalize,
-                               DivergingNorm)
+                               TwoSlopeNorm)
 from matplotlib.colorbar import ColorbarBase, _ColorbarLogLocator
 from matplotlib.ticker import LogLocator, LogFormatter, FixedLocator
 
@@ -52,10 +52,10 @@ def _colorbar_extension_shape(spacing):
         # Create a subplot.
         cax = fig.add_subplot(4, 1, i + 1)
         # Generate the colorbar.
-        cb = ColorbarBase(cax, cmap=cmap, norm=norm,
-                boundaries=boundaries, values=values,
-                extend=extension_type, extendrect=True,
-                orientation='horizontal', spacing=spacing)
+        ColorbarBase(cax, cmap=cmap, norm=norm,
+                     boundaries=boundaries, values=values,
+                     extend=extension_type, extendrect=True,
+                     orientation='horizontal', spacing=spacing)
         # Turn off text and ticks.
         cax.tick_params(left=False, labelleft=False,
                         bottom=False, labelbottom=False)
@@ -94,10 +94,8 @@ def _colorbar_extension_length(spacing):
     return fig
 
 
-@image_comparison(
-        baseline_images=['colorbar_extensions_shape_uniform',
-                         'colorbar_extensions_shape_proportional'],
-        extensions=['png'])
+@image_comparison(['colorbar_extensions_shape_uniform.png',
+                   'colorbar_extensions_shape_proportional.png'])
 def test_colorbar_extension_shape():
     '''Test rectangular colorbar extensions.'''
     # Create figures for uniform and proportionally spaced colorbars.
@@ -105,9 +103,8 @@ def test_colorbar_extension_shape():
     _colorbar_extension_shape('proportional')
 
 
-@image_comparison(baseline_images=['colorbar_extensions_uniform',
-                                   'colorbar_extensions_proportional'],
-                  extensions=['png'])
+@image_comparison(['colorbar_extensions_uniform.png',
+                   'colorbar_extensions_proportional.png'])
 def test_colorbar_extension_length():
     '''Test variable length colorbar extensions.'''
     # Create figures for uniform and proportionally spaced colorbars.
@@ -115,11 +112,11 @@ def test_colorbar_extension_length():
     _colorbar_extension_length('proportional')
 
 
-@image_comparison(baseline_images=['cbar_with_orientation',
-                                   'cbar_locationing',
-                                   'double_cbar',
-                                   'cbar_sharing',
-                                   ],
+@image_comparison(['cbar_with_orientation',
+                   'cbar_locationing',
+                   'double_cbar',
+                   'cbar_sharing',
+                   ],
                   extensions=['png'], remove_text=True,
                   savefig_kwarg={'dpi': 40})
 def test_colorbar_positioning():
@@ -173,8 +170,7 @@ def test_colorbar_positioning():
                  anchor=(0.8, 0.5), shrink=0.6, use_gridspec=False)
 
 
-@image_comparison(baseline_images=['cbar_with_subplots_adjust'],
-                  extensions=['png'], remove_text=True,
+@image_comparison(['cbar_with_subplots_adjust.png'], remove_text=True,
                   savefig_kwarg={'dpi': 40})
 def test_gridspec_make_colorbar():
     plt.figure()
@@ -192,8 +188,7 @@ def test_gridspec_make_colorbar():
     plt.subplots_adjust(top=0.95, right=0.95, bottom=0.2, hspace=0.25)
 
 
-@image_comparison(baseline_images=['colorbar_single_scatter'],
-                  extensions=['png'], remove_text=True,
+@image_comparison(['colorbar_single_scatter.png'], remove_text=True,
                   savefig_kwarg={'dpi': 40})
 def test_colorbar_single_scatter():
     # Issue #2642: if a path collection has only one entry,
@@ -231,9 +226,7 @@ def test_colorbarbase():
     ColorbarBase(ax, plt.cm.bone)
 
 
-@image_comparison(
-    baseline_images=['colorbar_closed_patch'],
-    remove_text=True)
+@image_comparison(['colorbar_closed_patch'], remove_text=True)
 def test_colorbar_closed_patch():
     fig = plt.figure(figsize=(8, 6))
     ax1 = fig.add_axes([0.05, 0.85, 0.9, 0.1])
@@ -320,19 +313,17 @@ def test_colorbar_minorticks_on_off():
 
     # test that minorticks turn off for LogNorm
     cbar.minorticks_off()
-    assert np.array_equal(cbar.ax.yaxis.get_minorticklocs(),
-                          np.array([]))
+    np.testing.assert_equal(cbar.ax.yaxis.get_minorticklocs(), [])
 
     # test that minorticks turn back on for LogNorm
     cbar.minorticks_on()
-    assert np.array_equal(cbar.ax.yaxis.get_minorticklocs(),
-                          default_minorticklocks)
+    np.testing.assert_equal(cbar.ax.yaxis.get_minorticklocs(),
+                            default_minorticklocks)
 
     # test issue #13339: minorticks for LogNorm should stay off
     cbar.minorticks_off()
     cbar.set_ticks([3, 5, 7, 9])
-    assert np.array_equal(cbar.ax.yaxis.get_minorticklocs(),
-                          np.array([]))
+    np.testing.assert_equal(cbar.ax.yaxis.get_minorticklocs(), [])
 
 
 def test_colorbar_autoticks():
@@ -384,7 +375,6 @@ def test_colorbar_get_ticks():
     data = np.arange(1200).reshape(30, 40)
     levels = [0, 200, 400, 600, 800, 1000, 1200]
 
-    plt.subplot()
     plt.contourf(data, levels=levels)
 
     # testing getter for user set ticks
@@ -451,8 +441,8 @@ def test_colorbar_renorm():
     fig, ax = plt.subplots()
     im = ax.imshow(z)
     cbar = fig.colorbar(im)
-    assert np.allclose(cbar.ax.yaxis.get_majorticklocs(),
-                       np.arange(0, 120000.1, 15000))
+    np.testing.assert_allclose(cbar.ax.yaxis.get_majorticklocs(),
+                               np.arange(0, 120000.1, 15000))
 
     cbar.set_ticks([1, 2, 3])
     assert isinstance(cbar.locator, FixedLocator)
@@ -460,14 +450,14 @@ def test_colorbar_renorm():
     norm = LogNorm(z.min(), z.max())
     im.set_norm(norm)
     assert isinstance(cbar.locator, _ColorbarLogLocator)
-    assert np.allclose(cbar.ax.yaxis.get_majorticklocs(),
-                       np.logspace(-8, 5, 14))
+    np.testing.assert_allclose(cbar.ax.yaxis.get_majorticklocs(),
+                               np.logspace(-8, 5, 14))
     # note that set_norm removes the FixedLocator...
     assert np.isclose(cbar.vmin, z.min())
     cbar.set_ticks([1, 2, 3])
     assert isinstance(cbar.locator, FixedLocator)
-    assert np.allclose(cbar.ax.yaxis.get_majorticklocs(),
-                       [1.0, 2.0, 3.0])
+    np.testing.assert_allclose(cbar.ax.yaxis.get_majorticklocs(),
+                               [1.0, 2.0, 3.0])
 
     norm = LogNorm(z.min() * 1000, z.max() * 1000)
     im.set_norm(norm)
@@ -514,7 +504,7 @@ def test_colorbar_scale_reset():
     assert cbar.ax.yaxis.get_scale() == 'linear'
 
 
-def test_colorbar_get_ticks():
+def test_colorbar_get_ticks_2():
     with rc_context({'_internal.classic_mode': False}):
 
         fig, ax = plt.subplots()
@@ -545,7 +535,7 @@ def test_colorbar_inverted_ticks():
 
 
 def test_extend_colorbar_customnorm():
-    # This was a funny error with DivergingNorm, maybe with other norms,
+    # This was a funny error with TwoSlopeNorm, maybe with other norms,
     # when extend='both'
     N = 100
     X, Y = np.mgrid[-3:3:complex(0, N), -2:2:complex(0, N)]
@@ -555,7 +545,7 @@ def test_extend_colorbar_customnorm():
 
     fig, ax = plt.subplots(2, 1)
     pcm = ax[0].pcolormesh(X, Y, Z,
-                           norm=DivergingNorm(vcenter=0., vmin=-2, vmax=1),
+                           norm=TwoSlopeNorm(vcenter=0., vmin=-2, vmax=1),
                            cmap='RdBu_r')
     cb = fig.colorbar(pcm, ax=ax[0], extend='both')
     np.testing.assert_allclose(cb.ax.get_position().extents,
@@ -568,3 +558,35 @@ def test_mappable_no_alpha():
     fig.colorbar(sm)
     sm.set_cmap('plasma')
     plt.draw()
+
+
+def test_colorbar_label():
+    """
+    Test the label parameter. It should just be mapped to the xlabel/ylabel of
+    the axes, depending on the orientation.
+    """
+    fig, ax = plt.subplots()
+    im = ax.imshow([[1, 2], [3, 4]])
+    cbar = fig.colorbar(im, label='cbar')
+    assert cbar.ax.get_ylabel() == 'cbar'
+    cbar.set_label(None)
+    assert cbar.ax.get_ylabel() == ''
+    cbar.set_label('cbar 2')
+    assert cbar.ax.get_ylabel() == 'cbar 2'
+
+    cbar2 = fig.colorbar(im, label=None)
+    assert cbar2.ax.get_ylabel() == ''
+
+    cbar3 = fig.colorbar(im, orientation='horizontal', label='horizontal cbar')
+    assert cbar3.ax.get_xlabel() == 'horizontal cbar'
+
+
+@pytest.mark.parametrize("clim", [(-20000, 20000), (-32768, 0)])
+def test_colorbar_int(clim):
+    # Check that we cast to float early enough to not
+    # overflow ``int16(20000) - int16(-20000)`` or
+    # run into ``abs(int16(-32768)) == -32768``.
+    fig, ax = plt.subplots()
+    im = ax.imshow([[*map(np.int16, clim)]])
+    fig.colorbar(im)
+    assert (im.norm.vmin, im.norm.vmax) == clim
