@@ -5,59 +5,54 @@ Usage Guide
 
 This tutorial covers some basic usage patterns and best-practices to
 help you get started with Matplotlib.
-
-.. _general_concepts:
-
-General Concepts
-================
-
-:mod:`matplotlib` has an extensive codebase that can be daunting to many
-new users. However, most of matplotlib can be understood with a fairly
-simple conceptual framework and knowledge of a few important points.
-
-Plotting requires action on a range of levels, from the most general
-(e.g., 'contour this 2-D array') to the most specific (e.g., 'color
-this screen pixel red'). The purpose of a plotting package is to assist
-you in visualizing your data as easily as possible, with all the necessary
-control -- that is, by using relatively high-level commands most of
-the time, and still have the ability to use the low-level commands when
-needed.
-
-Therefore, everything in matplotlib is organized in a hierarchy. At the top
-of the hierarchy is the matplotlib "state-machine environment" which is
-provided by the :mod:`matplotlib.pyplot` module. At this level, simple
-functions are used to add plot elements (lines, images, text, etc.) to
-the current axes in the current figure.
-
-.. note::
-
-   Pyplot's state-machine environment behaves similarly to MATLAB and
-   should be most familiar to users with MATLAB experience.
-
-The next level down in the hierarchy is the first level of the object-oriented
-interface, in which pyplot is used only for a few functions such as figure
-creation, and the user explicitly creates and keeps track of the figure
-and axes objects. At this level, the user uses pyplot to create figures,
-and through those figures, one or more axes objects can be created. These
-axes objects are then used for most plotting actions.
-
-For even more control -- which is essential for things like embedding
-matplotlib plots in GUI applications -- the pyplot level may be dropped
-completely, leaving a purely object-oriented approach.
 """
 
 # sphinx_gallery_thumbnail_number = 3
 import matplotlib.pyplot as plt
 import numpy as np
 
+##############################################################################
+#
+# A simple example
+# ================
+#
+# Matplotlib graphs your data on `~.figure.Figure`\s (i.e., windows, Jupyter
+# widgets, etc.), each of which can contain one or more `~.axes.Axes` (i.e., an
+# area where points can be specified in terms of x-y coordinates (or theta-r
+# in a polar plot, or x-y-z in a 3D plot, etc.).  The most simple way of
+# creating a figure with an axes is using `.pyplot.subplots`. We can then use
+# `.Axes.plot` to draw some data on the axes:
+
+fig, ax = plt.subplots()  # Create a figure containing a single axes.
+ax.plot([1, 2, 3, 4], [1, 4, 2, 3])  # Plot some data on the axes.
+
+###############################################################################
+# Many other plotting libraries or languages do not require you to explicitly
+# create an axes.  For example, in MATLAB, one can just do
+#
+# .. code-block:: matlab
+#
+#    plot([1, 2, 3, 4], [1, 4, 2, 3])  % MATLAB plot.
+#
+# and get the desired graph.
+#
+# In fact, you can do the same in Matplotlib: for each `~.axes.Axes` graphing
+# method, there is a corresponding function in the :mod:`matplotlib.pyplot`
+# module that performs that plot on the "current" axes, creating that axes (and
+# its parent figure) if they don't exist yet.  So the previous example can be
+# written more shortly as
+
+plt.plot([1, 2, 3, 4], [1, 4, 2, 3])  # Matplotlib plot.
+
 ###############################################################################
 # .. _figure_parts:
 #
 # Parts of a Figure
 # =================
 #
-# .. image:: ../../_static/anatomy.png
+# Now, let's have a deeper look at the components of a Matplotlib figure.
 #
+# .. image:: ../../_static/anatomy.png
 #
 # :class:`~matplotlib.figure.Figure`
 # ----------------------------------
@@ -67,19 +62,19 @@ import numpy as np
 # 'special' artists (titles, figure legends, etc), and the **canvas**.
 # (Don't worry too much about the canvas, it is crucial as it is the
 # object that actually does the drawing to get you your plot, but as the
-# user it is more-or-less invisible to you).  A figure can have any
-# number of :class:`~matplotlib.axes.Axes`, but to be useful should have
+# user it is more-or-less invisible to you).  A figure can contain any
+# number of :class:`~matplotlib.axes.Axes`, but will typically have
 # at least one.
 #
-# The easiest way to create a new figure is with pyplot:
-
-fig = plt.figure()  # an empty figure with no axes
-fig.suptitle('No axes on this figure')  # Add a title so we know which it is
-
-fig, ax_lst = plt.subplots(2, 2)  # a figure with a 2x2 grid of Axes
-
-
-###############################################################################
+# The easiest way to create a new figure is with pyplot::
+#
+#    fig = plt.figure()  # an empty figure with no Axes
+#    fig, ax = plt.subplots()  # a figure with a single Axes
+#    fig, axs = plt.subplots(2, 2)  # a figure with a 2x2 grid of Axes
+#
+# It's convenient to create the axes together with the figure, but you can
+# also add axes later on, allowing for more complex axes layouts.
+#
 # :class:`~matplotlib.axes.Axes`
 # ------------------------------
 #
@@ -90,15 +85,13 @@ fig, ax_lst = plt.subplots(2, 2)  # a figure with a 2x2 grid of Axes
 # Axes contains two (or three in the case of 3D)
 # :class:`~matplotlib.axis.Axis` objects (be aware of the difference
 # between **Axes** and **Axis**) which take care of the data limits (the
-# data limits can also be controlled via set via the
-# :meth:`~matplotlib.axes.Axes.set_xlim` and
-# :meth:`~matplotlib.axes.Axes.set_ylim` :class:`Axes` methods).  Each
-# :class:`Axes` has a title (set via
-# :meth:`~matplotlib.axes.Axes.set_title`), an x-label (set via
+# data limits can also be controlled via the :meth:`.axes.Axes.set_xlim` and
+# :meth:`.axes.Axes.set_ylim` methods).  Each :class:`~.axes.Axes` has a title
+# (set via :meth:`~matplotlib.axes.Axes.set_title`), an x-label (set via
 # :meth:`~matplotlib.axes.Axes.set_xlabel`), and a y-label set via
 # :meth:`~matplotlib.axes.Axes.set_ylabel`).
 #
-# The :class:`Axes` class and its member functions are the primary entry
+# The :class:`~.axes.Axes` class and its member functions are the primary entry
 # point to working with the OO interface.
 #
 # :class:`~matplotlib.axis.Axis`
@@ -106,129 +99,109 @@ fig, ax_lst = plt.subplots(2, 2)  # a figure with a 2x2 grid of Axes
 #
 # These are the number-line-like objects. They take
 # care of setting the graph limits and generating the ticks (the marks
-# on the axis) and ticklabels (strings labeling the ticks).  The
-# location of the ticks is determined by a
-# :class:`~matplotlib.ticker.Locator` object and the ticklabel strings
-# are formatted by a :class:`~matplotlib.ticker.Formatter`.  The
-# combination of the correct :class:`Locator` and :class:`Formatter` gives
-# very fine control over the tick locations and labels.
+# on the axis) and ticklabels (strings labeling the ticks).  The location of
+# the ticks is determined by a `~matplotlib.ticker.Locator` object and the
+# ticklabel strings are formatted by a `~matplotlib.ticker.Formatter`.  The
+# combination of the correct `.Locator` and `.Formatter` gives very fine
+# control over the tick locations and labels.
 #
 # :class:`~matplotlib.artist.Artist`
 # ----------------------------------
 #
 # Basically everything you can see on the figure is an artist (even the
-# :class:`Figure`, :class:`Axes`, and :class:`Axis` objects).  This
-# includes :class:`Text` objects, :class:`Line2D` objects,
-# :class:`collection` objects, :class:`Patch` objects ... (you get the
-# idea).  When the figure is rendered, all of the artists are drawn to
-# the **canvas**.  Most Artists are tied to an Axes; such an Artist
-# cannot be shared by multiple Axes, or moved from one to another.
+# `.Figure`, `Axes <.axes.Axes>`, and `~.axis.Axis` objects).  This includes
+# `.Text` objects, `.Line2D` objects, :mod:`.collections` objects, `.Patch`
+# objects ... (you get the idea).  When the figure is rendered, all of the
+# artists are drawn to the **canvas**.  Most Artists are tied to an Axes; such
+# an Artist cannot be shared by multiple Axes, or moved from one to another.
 #
 # .. _input_types:
 #
 # Types of inputs to plotting functions
 # =====================================
 #
-# All of plotting functions expect `np.array` or `np.ma.masked_array` as
+# All of plotting functions expect `numpy.array` or `numpy.ma.masked_array` as
 # input.  Classes that are 'array-like' such as `pandas` data objects
-# and `np.matrix` may or may not work as intended.  It is best to
-# convert these to `np.array` objects prior to plotting.
+# and `numpy.matrix` may or may not work as intended.  It is best to
+# convert these to `numpy.array` objects prior to plotting.
 #
 # For example, to convert a `pandas.DataFrame` ::
 #
 #   a = pandas.DataFrame(np.random.rand(4,5), columns = list('abcde'))
 #   a_asarray = a.values
 #
-# and to convert a `np.matrix` ::
+# and to convert a `numpy.matrix` ::
 #
-#   b = np.matrix([[1,2],[3,4]])
+#   b = np.matrix([[1, 2], [3, 4]])
 #   b_asarray = np.asarray(b)
 #
-# .. _pylab:
-#
-# Matplotlib, pyplot and pylab: how are they related?
-# ====================================================
-#
-# Matplotlib is the whole package and :mod:`matplotlib.pyplot` is a module in
-# Matplotlib.
-#
-# For functions in the pyplot module, there is always a "current" figure and
-# axes (which is created automatically on request).  For example, in the
-# following example, the first call to ``plt.plot`` creates the axes, then
-# subsequent calls to ``plt.plot`` add additional lines on the same axes, and
-# ``plt.xlabel``, ``plt.ylabel``, ``plt.title`` and ``plt.legend`` set the
-# axes labels and title and add a legend.
-
-x = np.linspace(0, 2, 100)
-
-plt.plot(x, x, label='linear')
-plt.plot(x, x**2, label='quadratic')
-plt.plot(x, x**3, label='cubic')
-
-plt.xlabel('x label')
-plt.ylabel('y label')
-
-plt.title("Simple Plot")
-
-plt.legend()
-
-plt.show()
-
-###############################################################################
-# :mod:`pylab` is a convenience module that bulk imports
-# :mod:`matplotlib.pyplot` (for plotting) and :mod:`numpy`
-# (for mathematics and working with arrays) in a single namespace.
-# pylab is deprecated and its use is strongly discouraged because
-# of namespace pollution. Use pyplot instead.
-#
-# For non-interactive plotting it is suggested
-# to use pyplot to create the figures and then the OO interface for
-# plotting.
-#
 # .. _coding_styles:
 #
-# Coding Styles
-# ==================
+# The object-oriented interface and the pyplot interface
+# ======================================================
 #
-# When viewing this documentation and examples, you will find different
-# coding styles and usage patterns. These styles are perfectly valid
-# and have their pros and cons. Just about all of the examples can be
-# converted into another style and achieve the same results.
-# The only caveat is to avoid mixing the coding styles for your own code.
+# As noted above, there are essentially two ways to use Matplotlib:
 #
-# .. note::
-#    Developers for matplotlib have to follow a specific style and guidelines.
-#    See :ref:`developers-guide-index`.
+# - Explicitly create figures and axes, and call methods on them (the
+#   "object-oriented (OO) style").
+# - Rely on pyplot to automatically create and manage the figures and axes, and
+#   use pyplot functions for plotting.
 #
-# Of the different styles, there are two that are officially supported.
-# Therefore, these are the preferred ways to use matplotlib.
-#
-# For the pyplot style, the imports at the top of your
-# scripts will typically be::
-#
-#     import matplotlib.pyplot as plt
-#     import numpy as np
-#
-# Then one calls, for example, np.arange, np.zeros, np.pi, plt.figure,
-# plt.plot, plt.show, etc.  Use the pyplot interface
-# for creating figures, and then use the object methods for the rest:
+# So one can do (OO-style)
 
-x = np.arange(0, 10, 0.2)
-y = np.sin(x)
-fig, ax = plt.subplots()
-ax.plot(x, y)
-plt.show()
+x = np.linspace(0, 2, 100)
+
+# Note that even in the OO-style, we use `.pyplot.figure` to create the figure.
+fig, ax = plt.subplots()  # Create a figure and an axes.
+ax.plot(x, x, label='linear')  # Plot some data on the axes.
+ax.plot(x, x**2, label='quadratic')  # Plot more data on the axes...
+ax.plot(x, x**3, label='cubic')  # ... and some more.
+ax.set_xlabel('x label')  # Add an x-label to the axes.
+ax.set_ylabel('y label')  # Add a y-label to the axes.
+ax.set_title("Simple Plot")  # Add a title to the axes.
+ax.legend()  # Add a legend.
 
 ###############################################################################
-# So, why all the extra typing instead of the MATLAB-style (which relies
-# on global state and a flat namespace)?  For very simple things like
-# this example, the only advantage is academic: the wordier styles are
-# more explicit, more clear as to where things come from and what is
-# going on.  For more complicated applications, this explicitness and
-# clarity becomes increasingly valuable, and the richer and more
-# complete object-oriented interface will likely make the program easier
-# to write and maintain.
+# or (pyplot-style)
+
+x = np.linspace(0, 2, 100)
+
+plt.plot(x, x, label='linear')  # Plot some data on the (implicit) axes.
+plt.plot(x, x**2, label='quadratic')  # etc.
+plt.plot(x, x**3, label='cubic')
+plt.xlabel('x label')
+plt.ylabel('y label')
+plt.title("Simple Plot")
+plt.legend()
+
+###############################################################################
+# Actually there is a third approach, for the case where you are embedding
+# Matplotlib in a GUI application, which completely drops pyplot, even for
+# figure creation.  We won't discuss it here; see the corresponding section in
+# the gallery for more info (:ref:`user_interfaces`).
 #
+# Matplotlib's documentation and examples use both the OO and the pyplot
+# approaches (which are equally powerful), and you should feel free to use
+# either (however, it is preferable pick one of them and stick to it, instead
+# of mixing them).  In general, we suggest to restrict pyplot to interactive
+# plotting (e.g., in a Jupyter notebook), and to prefer the OO-style for
+# non-interactive plotting (in functions and scripts that are intended to be
+# reused as part of a larger project).
+#
+# .. note::
+#
+#    In older examples, you may find examples that instead used the so-called
+#    ``pylab`` interface, via ``from pylab import *``. This star-import
+#    imports everything both from pyplot and from :mod:`numpy`, so that one
+#    could do ::
+#
+#       x = linspace(0, 2, 100)
+#       plot(x, x, label='linear')
+#       ...
+#
+#    for an even more MATLAB-like style.  This approach is strongly discouraged
+#    nowadays and deprecated; it is only mentioned here because you may still
+#    encounter it in the wild.
 #
 # Typically one finds oneself making the same plots over and over
 # again, but with different data sets, which leads to needing to write
@@ -262,6 +235,7 @@ def my_plotter(ax, data1, data2, param_dict):
     out = ax.plot(data1, data2, **param_dict)
     return out
 
+###############################################################################
 # which you would then use as:
 
 data1, data2, data3, data4 = np.random.randn(4, 100)
@@ -270,12 +244,13 @@ my_plotter(ax, data1, data2, {'marker': 'x'})
 
 ###############################################################################
 # or if you wanted to have 2 sub-plots:
+
 fig, (ax1, ax2) = plt.subplots(1, 2)
 my_plotter(ax1, data1, data2, {'marker': 'x'})
 my_plotter(ax2, data3, data4, {'marker': 'o'})
 
 ###############################################################################
-# Again, for these simple examples this style seems like overkill, however
+# For these simple examples this style seems like overkill, however
 # once the graphs get slightly more complex it pays off.
 #
 #
@@ -310,58 +285,82 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # "interactive backends") and hardcopy backends to make image files
 # (PNG, SVG, PDF, PS; also referred to as "non-interactive backends").
 #
-# There are four ways to configure your backend. If they conflict each other,
-# the method mentioned last in the following list will be used, e.g. calling
-# :func:`~matplotlib.use()` will override the setting in your ``matplotlibrc``.
+# Selecting a backend
+# -------------------
 #
+# There are three ways to configure your backend:
 #
-# #. The ``backend`` parameter in your ``matplotlibrc`` file (see
-#    :doc:`/tutorials/introductory/customizing`)::
+# 1. The :rc:`backend` parameter in your ``matplotlibrc`` file
+# 2. The :envvar:`MPLBACKEND` environment variable
+# 3. The function :func:`matplotlib.use`
 #
-#        backend : WXAgg   # use wxpython with antigrain (agg) rendering
+# A more detailed description is given below.
 #
-# #. Setting the :envvar:`MPLBACKEND` environment variable, either for your
-#    current shell or for a single script.  On Unix::
+# If multiple of these are configurations are present, the last one from the
+# list takes precedence; e.g. calling :func:`matplotlib.use()` will override
+# the setting in your ``matplotlibrc``.
 #
-#         > export MPLBACKEND=module://my_backend
+# If no backend is explicitly set, Matplotlib automatically detects a usable
+# backend based on what is available on your system and on whether a GUI event
+# loop is already running. On Linux, if the environment variable
+# :envvar:`DISPLAY` is unset, the "event loop" is identified as "headless",
+# which causes a fallback to a noninteractive backend (agg).
+#
+# Here is a detailed description of the configuration methods:
+#
+# #. Setting :rc:`backend` in your ``matplotlibrc`` file::
+#
+#        backend : qt5agg   # use pyqt5 with antigrain (agg) rendering
+#
+#    See also :doc:`/tutorials/introductory/customizing`.
+#
+# #. Setting the :envvar:`MPLBACKEND` environment variable:
+#
+#    You can set the environment variable either for your current shell or for
+#    a single script.
+#
+#    On Unix::
+#
+#         > export MPLBACKEND=qt5agg
 #         > python simple_plot.py
 #
-#         > MPLBACKEND="module://my_backend" python simple_plot.py
+#         > MPLBACKEND=qt5agg python simple_plot.py
 #
 #    On Windows, only the former is possible::
 #
-#         > set MPLBACKEND=module://my_backend
+#         > set MPLBACKEND=qt5agg
 #         > python simple_plot.py
 #
 #    Setting this environment variable will override the ``backend`` parameter
 #    in *any* ``matplotlibrc``, even if there is a ``matplotlibrc`` in your
-#    current working directory. Therefore setting :envvar:`MPLBACKEND`
+#    current working directory. Therefore, setting :envvar:`MPLBACKEND`
 #    globally, e.g. in your ``.bashrc`` or ``.profile``, is discouraged as it
 #    might lead to counter-intuitive behavior.
 #
-# #. If your script depends on a specific backend you can use the
-#    :func:`~matplotlib.use` function::
+# #. If your script depends on a specific backend you can use the function
+#    :func:`matplotlib.use`::
 #
 #       import matplotlib
-#       matplotlib.use('PS')   # generate postscript output by default
+#       matplotlib.use('qt5agg')
 #
-#    If you use the :func:`~matplotlib.use` function, this must be done before
-#    importing :mod:`matplotlib.pyplot`. Calling :func:`~matplotlib.use` after
-#    pyplot has been imported will have no effect.  Using
-#    :func:`~matplotlib.use` will require changes in your code if users want to
+#    This should be done before any figure is created; otherwise Matplotlib may
+#    fail to switch the backend and raise an ImportError.
+#
+#    Using `~matplotlib.use` will require changes in your code if users want to
 #    use a different backend.  Therefore, you should avoid explicitly calling
-#    :func:`~matplotlib.use` unless absolutely necessary.
+#    `~matplotlib.use` unless absolutely necessary.
 #
-# .. note::
-#    Backend name specifications are not case-sensitive; e.g., 'GTK3Agg'
-#    and 'gtk3agg' are equivalent.
 #
-# With a typical installation of matplotlib, such as from a
-# binary installer or a linux distribution package, a good default
-# backend will already be set, allowing both interactive work and
-# plotting from scripts, with output to the screen and/or to
-# a file, so at least initially you will not need to use any of the
-# methods given above.
+# The builtin backends
+# --------------------
+#
+# By default, Matplotlib should automatically select a default backend which
+# allows both interactive work and plotting from scripts, with output to the
+# screen and/or to a file, so at least initially you will not need to worry
+# about the backend.  The most common exception is if your Python distribution
+# comes without :mod:`tkinter` and you have no other GUI toolkit installed;
+# this happens on certain Linux distributions, where you need to install a
+# Linux package named ``python-tk`` (or similar).
 #
 # If, however, you want to write graphical user interfaces, or a web
 # application server (:ref:`howto-webapp`), or need a better
@@ -370,12 +369,10 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # the concept of the renderer (the thing that actually does the drawing)
 # from the canvas (the place where the drawing goes).  The canonical
 # renderer for user interfaces is ``Agg`` which uses the `Anti-Grain
-# Geometry`_ C++ library to make a raster (pixel) image of the figure.
-# All of the user interfaces except ``macosx`` can be used with
-# agg rendering, e.g., ``WXAgg``, ``GTK3Agg``, ``QT4Agg``, ``QT5Agg``,
-# ``TkAgg``.  In addition, some of the user interfaces support other rendering
-# engines.  For example, with GTK+ 3, you can also select Cairo rendering
-# (backend ``GTK3Cairo``).
+# Geometry`_ C++ library to make a raster (pixel) image of the figure; it
+# is used by the ``Qt5Agg``, ``Qt4Agg``, ``GTK3Agg``, ``wxAgg``, ``TkAgg``, and
+# ``macosx`` backends.  An alternative renderer is based on the Cairo library,
+# used by ``Qt5Cairo``, ``Qt4Cairo``, etc.
 #
 # For the rendering engines, one can also distinguish between `vector
 # <https://en.wikipedia.org/wiki/Vector_graphics>`_ or `raster
@@ -389,22 +386,18 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # backend for each; these are *non-interactive backends*, capable of
 # writing to a file):
 #
-# =============   ============   ================================================
-# Renderer        Filetypes      Description
-# =============   ============   ================================================
-# :term:`AGG`     :term:`png`    :term:`raster graphics` -- high quality images
-#                                using the `Anti-Grain Geometry`_ engine
-# PS              :term:`ps`     :term:`vector graphics` -- Postscript_ output
-#                 :term:`eps`
-# PDF             :term:`pdf`    :term:`vector graphics` --
-#                                `Portable Document Format`_
-# SVG             :term:`svg`    :term:`vector graphics` --
-#                                `Scalable Vector Graphics`_
-# :term:`Cairo`   :term:`png`    :term:`raster graphics` and
-#                 :term:`ps`     :term:`vector graphics` -- using the
-#                 :term:`pdf`    `Cairo graphics`_ library
-#                 :term:`svg`
-# =============   ============   ================================================
+# ========  =========  =======================================================
+# Renderer  Filetypes  Description
+# ========  =========  =======================================================
+# AGG       png        raster_ graphics -- high quality images using the
+#                      `Anti-Grain Geometry`_ engine
+# PS        ps,        vector_ graphics -- Postscript_ output
+#           eps
+# PDF       pdf        vector_ graphics -- `Portable Document Format`_
+# SVG       svg        vector_ graphics -- `Scalable Vector Graphics`_
+# Cairo     png, ps,   raster_ or vector_ graphics -- using the Cairo_ library
+#           pdf, svg
+# ========  =========  =======================================================
 #
 # To save plots using the non-interactive backends, use the
 # ``matplotlib.pyplot.savefig('filename')`` method.
@@ -439,25 +432,29 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # Qt4Agg    Agg rendering to a :term:`Qt4` canvas (requires PyQt4_ or
 #           ``pyside``).  This backend can be activated in IPython with
 #           ``%matplotlib qt4``.
-# WXAgg     Agg rendering to a :term:`wxWidgets` canvas (requires wxPython_ 4).
+# wxAgg     Agg rendering to a :term:`wxWidgets` canvas (requires wxPython_ 4).
 #           This backend can be activated in IPython with ``%matplotlib wx``.
 # ========= ================================================================
 #
+# .. note::
+#    The names of builtin backends case-insensitive; e.g., 'Qt5Agg' and
+#    'qt5agg' are equivalent.
+#
 # .. _`Anti-Grain Geometry`: http://antigrain.com/
 # .. _Postscript: https://en.wikipedia.org/wiki/PostScript
 # .. _`Portable Document Format`: https://en.wikipedia.org/wiki/Portable_Document_Format
 # .. _`Scalable Vector Graphics`: https://en.wikipedia.org/wiki/Scalable_Vector_Graphics
-# .. _`Cairo graphics`: https://wwW.cairographics.org
+# .. _Cairo: https://www.cairographics.org
 # .. _PyGObject: https://wiki.gnome.org/action/show/Projects/PyGObject
 # .. _pycairo: https://www.cairographics.org/pycairo/
 # .. _cairocffi: https://pythonhosted.org/cairocffi/
 # .. _wxPython: https://www.wxpython.org/
-# .. _TkInter: https://wiki.python.org/moin/TkInter
+# .. _TkInter: https://docs.python.org/3/library/tk.html
 # .. _PyQt4: https://riverbankcomputing.com/software/pyqt/intro
 # .. _PyQt5: https://riverbankcomputing.com/software/pyqt/intro
 #
 # ipympl
-# ------
+# ^^^^^^
 #
 # The Jupyter widget ecosystem is moving too fast to support directly in
 # Matplotlib.  To install ipympl
@@ -477,25 +474,34 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # for more details.
 #
 # GTK and Cairo
-# -------------
+# ^^^^^^^^^^^^^
 #
-# `GTK3` backends (*both* `GTK3Agg` and `GTK3Cairo`) depend on Cairo
+# ``GTK3`` backends (*both* ``GTK3Agg`` and ``GTK3Cairo``) depend on Cairo
 # (pycairo>=1.11.0 or cairocffi).
 #
+# .. _QT_API-usage:
+#
 # How do I select PyQt4 or PySide?
-# --------------------------------
+# ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 #
-# The `QT_API` environment variable can be set to either `pyqt` or `pyside`
-# to use `PyQt4` or `PySide`, respectively.
+# The :envvar:`QT_API` environment variable can be set to either ``pyqt`` or
+# ``pyside`` to use ``PyQt4`` or ``PySide``, respectively.
+#
+# Since the default value for the bindings to be used is ``PyQt4``, Matplotlib
+# first tries to import it, if the import fails, it tries to import ``PySide``.
+#
+# Using non-builtin backends
+# --------------------------
+# More generally, any importable backend can be selected by using any of the
+# methods above. If ``name.of.the.backend`` is the module containing the
+# backend, use ``module://name.of.the.backend`` as the backend name, e.g.
+# ``matplotlib.use('module://name.of.the.backend')``.
 #
-# Since the default value for the bindings to be used is `PyQt4`,
-# :mod:`matplotlib` first tries to import it, if the import fails, it tries to
-# import `PySide`.
 #
 # .. _interactive-mode:
 #
 # What is interactive mode?
-# ===================================
+# =========================
 #
 # Use of an interactive backend (see :ref:`what-is-a-backend`)
 # permits--but does not by itself require or ensure--plotting
@@ -528,7 +534,8 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 #    Interactive mode works with suitable backends in ipython and in
 #    the ordinary python shell, but it does *not* work in the IDLE IDE.
 #    If the default backend does not support interactivity, an interactive
-#    backend can be explicitly activated using any of the methods discussed in `What is a backend?`_.
+#    backend can be explicitly activated using any of the methods discussed
+#    in `What is a backend?`_.
 #
 #
 # Interactive example
@@ -541,23 +548,20 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 #     plt.ion()
 #     plt.plot([1.6, 2.7])
 #
-# Assuming you are running version 1.0.1 or higher, and you have
-# an interactive backend installed and selected by default, you should
-# see a plot, and your terminal prompt should also be active; you
-# can type additional commands such as::
+# This will pop up a plot window. Your terminal prompt will remain active, so
+# that you can type additional commands such as::
 #
 #     plt.title("interactive test")
 #     plt.xlabel("index")
 #
-# and you will see the plot being updated after each line.  Since version 1.5,
-# modifying the plot by other means *should* also automatically
-# update the display on most backends. Get a reference to the :class:`~matplotlib.axes.Axes` instance,
-# and call a method of that instance::
+# On most interactive backends, the figure window will also be updated if you
+# change it via the object-oriented interface. E.g. get a reference to the
+# `~matplotlib.axes.Axes` instance, and call a method of that instance::
 #
 #     ax = plt.gca()
 #     ax.plot([3.1, 2.2])
 #
-# If you are using certain backends (like `macosx`), or an older version
+# If you are using certain backends (like ``macosx``), or an older version
 # of matplotlib, you may not see the new line added to the plot immediately.
 # In this case, you need to explicitly call :func:`~matplotlib.pyplot.draw`
 # in order to update the plot::
@@ -582,22 +586,22 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 #     plt.show()
 #
 # Now you see the plot, but your terminal command line is
-# unresponsive; the :func:`show()` command *blocks* the input
+# unresponsive; the :func:`.pyplot.show()` command *blocks* the input
 # of additional commands until you manually kill the plot
 # window.
 #
 # What good is this--being forced to use a blocking function?
 # Suppose you need a script that plots the contents of a file
 # to the screen.  You want to look at that plot, and then end
-# the script.  Without some blocking command such as show(), the
+# the script.  Without some blocking command such as ``show()``, the
 # script would flash up the plot and then end immediately,
 # leaving nothing on the screen.
 #
 # In addition, non-interactive mode delays all drawing until
-# show() is called; this is more efficient than redrawing
+# ``show()`` is called; this is more efficient than redrawing
 # the plot each time a line in the script adds a new feature.
 #
-# Prior to version 1.0, show() generally could not be called
+# Prior to version 1.0, ``show()`` generally could not be called
 # more than once in a single script (although sometimes one
 # could get away with it); for version 1.0.1 and above, this
 # restriction is lifted, so one can write a script like this::
@@ -749,7 +753,7 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 #   # Setup, and create the data to plot
 #   y = np.random.rand(100000)
 #   y[50000:] *= 2
-#   y[np.logspace(1,np.log10(50000), 400).astype(int)] = -1
+#   y[np.logspace(1, np.log10(50000), 400).astype(int)] = -1
 #   mpl.rcParams['path.simplify'] = True
 #
 #   mpl.rcParams['agg.path.chunksize'] = 0
@@ -764,7 +768,7 @@ my_plotter(ax2, data3, data4, {'marker': 'o'})
 # -------
 #
 # The default legend behavior for axes attempts to find the location
-# that covers the fewest data points (`loc='best'`). This can be a
+# that covers the fewest data points (``loc='best'``). This can be a
 # very expensive computation if there are lots of data points. In
 # this case, you may want to provide a specific location.
 #
